Welcome to tsseg’s documentation!
==================================

.. include:: intro.rst

.. toctree::
   :maxdepth: 2

   guides/getting-started
   guides/datasets
   guides/detectors
   guides/contributing
   api/index
   changelog